@@ -7,6 +7,9 @@
 #' allocation. \emph{Journal of Banking and Finance}, 37, 2268-2283
 #'
 #' @param x A matrix.
+#' @param z A vector with the variable over which coefficients are smooth over.
+#' @param ez (optional) A scalar or vector with the smoothing values. If 
+#' values are not included then the vector \code{z} is used instead.
 #' @param bw A scalar.
 #' @param cv.block A positive scalar with the size of the block in leave-one block-out cross-validation.
 #' By default 'cv.block=0' meaning leave-one-out cross-validation.
@@ -40,7 +43,8 @@
 #'
 #' @export tvCov
 #'
-tvCov <- function(x, bw = NULL, cv.block = 0, est = c("lc", "ll"), tkernel = c("Triweight", "Epa", "Gaussian"))
+tvCov <- function(x, z = NULL, ez = NULL, bw = NULL, cv.block = 0, est = c("lc", "ll"), 
+                  tkernel = c("Triweight", "Epa", "Gaussian"))
 {
   if(!inherits(x, c("matrix", "data.frame")))
     stop("'x' should be a matrix or a data.frame.\n")
@@ -55,11 +59,20 @@ tvCov <- function(x, bw = NULL, cv.block = 0, est = c("lc", "ll"), tkernel = c("
     bw <- bwCov(x, cv.block = abs(cv.block), est, tkernel)
   if(length(bw) > 1)
     bw <- stats::median(bw)
-  time.grid <- 1:obs
+  if(!is.null(z))
+  {
+    if(length(z) != obs)
+      stop("\nDimensions of 'x' and 'z' are not compatible\n")
+    grid <- z
+  }
+  else
+    grid <- (1:obs)/obs
+  if (is.null(ez))
+    ez <- grid
   for (t in 1:obs)
   {
-    tau0 <- (time.grid - t)/obs
-    kernel.bw <- .kernel(tau0, bw, tkernel = tkernel)/bw
+    tau0 <- grid - ez[t]
+    kernel.bw <- .kernel(x = tau0, bw = bw, tkernel = tkernel)
     w0 <- sum(kernel.bw)
     r.2 <- matrix(0, neq, neq)
     if(est == "lc")
@@ -88,13 +101,14 @@ tvCov <- function(x, bw = NULL, cv.block = 0, est = c("lc", "ll"), tkernel = c("
 #' @name tvReg-internals
 #' @param x A matrix.
 #' @param bw A scalar.
+#' @param z A vector.
 #' @param est A character, either "lc" or "ll" for local constant or local linear.
 #' @param tkernel A character, either "Triweight" (default), "Epa" or "Gaussian" kernel function.
 #'
 #' @return A scalar with the mean squared error.
 #' @keywords internal
 #'
-.tvCov.cv <- function(bw, x, cv.block = 0, est = c("lc", "ll"), tkernel = c("Triweight", "Epa", "Gaussian"))
+.tvCov.cv <- function(bw, x, z = NULL, cv.block = 0, est = c("lc", "ll"), tkernel = c("Triweight", "Epa", "Gaussian"))
 {
   x <- as.matrix(x)
   obs <- NROW(x)
@@ -105,11 +119,18 @@ tvCov <- function(x, bw = NULL, cv.block = 0, est = c("lc", "ll"), tkernel = c("
   resid.2 <- numeric(obs)
   if(length(bw)>1) 
     bw <- stats::median(bw)
-  grid <- 1:obs/obs
+  if(!is.null(z))
+  {
+    if(length(z) != obs)
+      stop("\nDimensions of 'x' and 'z' are not compatible\n")
+    grid <- z
+  }
+  else
+    grid <- (1:obs)/obs
   for (t in 1:obs)
   {
     tau0 <- grid - grid[t]
-    kernel.bw <- .kernel(tau0, bw, tkernel = tkernel)/bw
+    kernel.bw <- .kernel(x = tau0, bw = bw, tkernel = tkernel)
     kernel.bw[max(1, t-cv.block):min(t+cv.block, obs)] <- 0
     w0 <- sum(kernel.bw)
     k.index <- which(kernel.bw != 0)
@@ -161,8 +182,8 @@ tvCov <- function(x, bw = NULL, cv.block = 0, est = c("lc", "ll"), tkernel = c("
 #' @aliases tvlm-class tvlm
 #' @param formula An object of class formula.
 #' @param z A vector with the smoothing variable.
-#' @param ez (optional) A scalar or vector with the smoothing estimation values. If 
-#' values are included then the vector \code{z} is used.
+#' @param ez (optional) A scalar or vector with the smoothing values. If 
+#' values are not included then the vector \code{z} is used instead.
 #' @param data An optional data frame or matrix.
 #' @param bw An opcional scalar. It represents the bandwidth in
 #' the estimation of trend coefficients. If NULL, it is selected by cross validation. 
